@@ -1,11 +1,13 @@
+from zope.interface import implements
+from zope.publisher.browser import TestRequest
+
 from Products.Five import zcml
 from Products.Five import fiveconfigure
 
-from Testing import ZopeTestCase as ztc
-
 from Products.PloneTestCase import PloneTestCase as ptc
 from Products.PloneTestCase.layer import onsetup
 
+from z3c.form.interfaces import IFormLayer
 
 @onsetup
 def setup_product():
@@ -19,13 +21,21 @@ def setup_product():
 
     fiveconfigure.debug_mode = False
 
-    #ztc.installPackage('collective.geo.settings')
 
 setup_product()
 ptc.setupPloneSite(products=['collective.geo.settings'])
 
-class GeoSettingsTestCase(ptc.PloneTestCase):
+
+class TestRequest(TestRequest):
+    implements(IFormLayer)
+
+
+class TestCase(ptc.PloneTestCase):
     pass
 
-class GeoSettingsFunctionalTestCase(ptc.FunctionalTestCase):
+    # def afterSetUp(self):
+    #     collective.geo.settings.fields.decimalPersistentFieldAdapter
+    #     
+
+class FunctionalTestCase(ptc.FunctionalTestCase):
     pass
